@@ -93,7 +93,7 @@ func main() {
 
 	var symlinks *bool
 	cmdName := CmdName()
-	if cmdName == "goredo" {
+	if cmdName == CmdNameGoredo {
 		symlinks = flag.Bool("symlinks", false, "create necessary symlinks in current directory")
 	}
 
